library(readxl)
library(SDAR)
setwd("D:/Limon/PAPERS_LM_LA_VENTA/STRAT_PAPER/SDAR_Plots")

##### COMPOSITE SECTION #####

setwd("D:/Limon/PAPERS_LM_LA_VENTA/STRAT_PAPER/SDAR_Plots")
vignette("SDAR_data_model")
beds <- read_excel("0_SDAR_v0.95_beds_template_22_11_2020.xlsx")
outcrop_validated_beds <- strata(beds, datum = "base")
class(outcrop_validated_beds)

summary(outcrop_validated_beds)
summary(outcrop_validated_beds, grain.size=TRUE)

thickness <- abs(outcrop_validated_beds[,"from"] - outcrop_validated_beds[, "to"])

boxplot(thickness ~ beds$prim_litho)

fpath <- "0_SDAR_v0.95_intervals_template_22_11_2020.xlsx"
meta_data<- read_excel(fpath, sheet="metadata")
samples_data <- read_excel(fpath, sheet = "samples")
sed_structures_data <- read_excel(fpath, sheet = "sed_structures")
fossils_data <- read_excel(fpath, sheet = "fossils")
other_symbols_data <- read_excel(fpath, sheet = "other_symbols")
litho_data <- read_excel(fpath, sheet = "lithostra")
ncore<- read_excel(fpath,sheet="core_number")

## Detailed stratigraphic column for Appendix 2
plot(outcrop_validated_beds, data.units="meters", family = "sans", 
     scale = 1000, barscale = 10, datum = "base",
     file.name = "0_Composite_section_Honda_G_4jan2020_1000", main = "Detailed composite section Honda Group",
     samples=samples_data, 
     sed.structures=sed_structures_data,
     fossils=fossils_data,
     other.sym=other_symbols_data,
     lithostrat=litho_data,
     symbols.size=0.6)

## Stratigraphic column for Fig 2
plot(outcrop_validated_beds, data.units="meters", family = "sans", 
     suppress.ref=T,
     scale = 6500, barscale = 10, datum = "base",
     file.name = "0_Composite_section_Honda_G_8jan2021_6500",
     samples=samples_data, 
     lithostrat=litho_data,
     symbols.size=0.6)


##### LV 1 SECTION #####

beds <- read_excel("1_LV_1_section_SDAR.xlsx")
beds_val <- strata(beds, datum="base")
int_path <- "1_LV_1_section_SDAR_intervals_template_v095.xlsx"

metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "LV 1", latitude = 3.39307, longitude=-75.14735, 
           elevation=416, author ="This work", cex.main =0.1, 
           country="Colombia", thickness_unit="meters")

plot(beds_val, datum="base", data.units = "meters" , scale=1000, barscale= 5, 
     file.name="LV 1.pdf_2", 
     main="LV 1", symbols.size=0.5,
     family = "sans", metadata = Meta)

##### LV 2 SECTION ######

beds <- read_excel("2_LV_2_section_SDAR.xlsx")
beds_val <- strata(beds, datum="base")
int_path <- "2_LV_2_section_intervals_template_v095.xlsx" 

metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "LV 2", latitude = 3.319579755, longitude=-75.1491999, 
           elevation=434, author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_val, datum="base", data.units = "meters" , scale=1000, barscale= 5, 
     file.name="2_LV_2.pdf_2", 
     main="LV_2", symbols.size=1,
     metadata = Meta,
     family = "sans")

###### LV 3 SECTION #####

beds <- read_excel("3_LV_3_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "3_LV_3_section_intervals_template_v095.xlsx" 

fossils <- read_excel(int_path, sheet = "fossils")
metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "LV 3", latitude = 3.26716661, longitude=-75.0944414, 
           elevation=475, author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters" , scale=1000, barscale= 5, 
     file.name="3_LV_3_section.pdf_2", 
     main="LV 3 section", symbols.size=1, metadata = Meta,  
     family = "sans")


##### LV 4 SECTION #####

beds <- read_excel("4_LV_4_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "4_LV_4_section_intervals_template_v095.xlsx" 

fossils <- read_excel(int_path, sheet = "fossils")
metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "LV 4", latitude = 3.26276431, longitude=-75.0981076, elevation=476,
           author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters" , scale=1000, barscale= 5, 
     file.name="4_LV_4_section.pdf_2", 
     main="LV 4 section", symbols.size=1,
     metadata = Meta,
     family = "sans")


###### LV_5 ######

beds <- read_excel("5_LV_5_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "5_LV_5_section_intervals_template_v095.xlsx" 

metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "LV_5", latitude = 3.234354672, longitude=-75.1246063, elevation=501,
           author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters" , scale=1000, barscale= 5, 
     file.name="5_LV_5_section.pdf_2", 
     main="LV 5 section", symbols.size=1,
     metadata = Meta,
     family = "sans")


###### LV 6 SECTION ######
beds <- read_excel("6_LV_6_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "6_LV_6_section_intervals_template_v095.xlsx" 

metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "LV 6", latitude = 3.229598498, longitude=-75.1298438, elevation=485,
           author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters" , scale=1000, barscale= 5, 
     file.name="6_LV_6.pdf_2", 
     main="LV 6 section", symbols.size=1, 
     family = "sans")


######### Vv 1 SECTION #######

beds <- read_excel("7_Vv_1_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "7_Vv_1_section_intervals_template_v095.xlsx" 

fossils <- read_excel(int_path, sheet = "fossils")
metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "Vv 1", latitude = 3.251907218, longitude=-75.1596548,
           elevation=420, author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters" , scale=1000, barscale= 5, 
     file.name="7_Vv_1_section.pdf_2", 
     main="Vv 1 section", symbols.size=1,
     metadata = Meta,
     family = "sans")


###### Vv 2 SECTION ######
beds <- read_excel("8_Vv_2_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "8_Vv_2_section_intervals_template_v095.xlsx" 

fossils <- read_excel(int_path, sheet = "fossils")
metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "Vv 2", latitude = 3.236959243, longitude=-75.1547973, elevation=443,
           author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters" , scale=1000, barscale= 5, 
     file.name="8_Vv_2_section.pdf_2", 
     main="Vv 2 section", symbols.size=1,
     metadata = Meta,
     family = "sans")


##### Vv 3 SECTION #####

beds <- read_excel("9_Vv_3_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "9_Vv_3_section_intervals_template_v095.xlsx" 

fossils <- read_excel(int_path, sheet = "fossils")
metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "Vv 3", latitude =3.234067088, longitude=-75.1676572, elevation=448,
           author ="This work", cex.main =0.1,reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters" , scale=1000, barscale=5,
     file.name="9_Vv_3_section.pdf_2", 
     main="Vv 3 section", symbols.size=1,
     metadata = Meta,
     family = "sans")


###### Vv 4 SECTION ######

beds <- read_excel("10_Vv_4_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "10_Vv_4_section_intervals_template_v095.xlsx" 

fossils <- read_excel(int_path, sheet = "fossils")
metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "Vv 4", latitude=3.229251694, longitude=-75.1718106, elevation=430,
           author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters", scale=1000, barscale= 5, 
     file.name="10_Vv_4_section.pdf_2", 
     main="Vv 4 section", symbols.size=1,
     metadata = Meta,
     family = "sans")


###### Vv 5 SECTION #######

beds <- read_excel("11_Vv_5_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "11_Vv_5_section_intervals_template_v095.xlsx" 

fossils <- read_excel(int_path, sheet = "fossils")
metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "Vv 5", latitude=3.234067088, longitude=-75.1676572, elevation=448,
           author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters", scale=1000, barscale=5,
     file.name="11_Vv_5_section.pdf_2", 
     main="Vv 5 section", symbols.size=1,
     metadata = Meta,
     family = "sans")


###### Vv 6 SECTION #######
beds <- read_excel("12_Vv_6_section_SDAR.xlsx")
beds_validate <- strata(beds, datum="base")
int_path <- "12_Vv_6_section_intervals_template_v095.xlsx" 

fossils <- read_excel(int_path, sheet = "fossils")
metadata <- read_excel(int_path, sheet = "metadata")
sed_struct <- read_excel(int_path, sheet = "sed_structure")
other_symbols <- read_excel(int_path, sheet = "others")
lithostra <- read_excel(int_path, sheet = "lithostra")
structural_data <- read_excel(int_path, sheet = "struct_data")

Meta<-list(locality_name = "Vv 6", latitude = 3.15754, longitude=-75.05787, elevation=624,
           author ="This work", cex.main =0.1, reference="Jaramillo et al. 2010",
           country="Colombia", thickness_unit="meters")

plot(beds_validate, datum="base", data.units = "meters", scale=1000, barscale=5,
     file.name="12_Vv 6_section.pdf_2", 
     main="Vv 6 section", symbols.size=1,
     metadata = Meta,
     family = "sans")

### PDFS merged with Ilovepdf app. 
